@@ -1,5 +1,5 @@
 #   Copyright 2022 Chang In Moon changin.moon@bcm.edu
-__version__ = '0.1.5'
+__version__ = '0.1.8'
 
 import io
 import pandas as pd
@@ -11,11 +11,11 @@ from .exceptions import BaseError, BaseWarning, InvalidParameterError, NoInterne
 def list_datasets():
     """List all available datasets."""
 
-    dataset_list_url = "https://bcm.box.com/shared/static/hfm7swxvy4x48j9a8novny2432gh750u.csv"
+    dataset_list_url = "https://bcm.box.com/shared/static/v24wiuyy73rhv8jn44tyjbs0al8wa6oe.csv"
 
     try:
         dataset_list_text = _download_text(dataset_list_url)
     except NoInternetError:
         raise NoInternetError("Insufficient internet to download available dataset info. Check your internet connection.") from None
 
-    return pd.read_csv(io.StringIO(dataset_list_text), header=True, index_col=0)
+    return pd.read_csv(io.StringIO(dataset_list_text), header=0)
