@@ -12,7 +12,7 @@ def get_dataset_link():
         dataset_link_text = _download_text(dataset_link_url)
     except NoInternetError:
         raise NoInternetError("Insufficient internet to download available dataset info. Check your internet connection.") from None
-    return pd.read_csv(io.StringIO(dataset_link_text), header=True, index_col=0)
+    return pd.read_csv(io.StringIO(dataset_link_text), header=0)
 
 def download(dataset):
     dataset = dataset.lower()
